@@ -3,11 +3,11 @@ use strict;
 use Filter::Simple;
 
 use vars '$VERSION';
-$VERSION = '0.11';
+$VERSION = '0.12';
 
 =head1 NAME
 
-Filter::signatures - very simplicistic signatures for Perl < 5.20
+Filter::signatures - very simplistic signatures for Perl < 5.20
 
 =head1 SYNOPSIS
 
@@ -33,8 +33,8 @@ signatures that were introduced to the Perl core with Perl 5.20.
 
 =head1 CAVEATS
 
-The technique used is a very simplicistic transform to allow for using very
-simplicistic named formal arguments in subroutine declarations. This module
+The technique used is a very simplistic transform to allow for using very
+simplistic named formal arguments in subroutine declarations. This module
 does not implement warning if more or fewer parameters than expected are
 passed in.
 
@@ -162,11 +162,16 @@ sub parse_argument_list {
                 $args[$_] = 'undef';
             }
         };
+
+        # Make sure we return undef as the last statement of our initialization
+        # See t/07*
+        push @defaults, "();" if @defaults;
+
         $res = sprintf 'sub %s { my (%s)=@_;%s%s', $name, join(",", @args), join( "" , @defaults), "\n" x $padding;
         # die sprintf("Too many arguments for subroutine at %s line %d.\n", (caller)[1, 2]) unless @_ <= 2
         # die sprintf("Too few arguments for subroutine at %s line %d.\n", (caller)[1, 2]) unless @_ >= 2
     } else {
-        $res = sprintf 'sub %s { @_==0 or warn "Subroutine %s called with parameters.";', $name, $name;
+        $res = sprintf 'sub %s { @_==0 or warn "Subroutine %s called with parameters.";();', $name, $name;
     };
 
     return $res
